pub type Fallback<B> = fn(ServiceRequest, &Error) -> Result<ServiceResponse<EitherBody<B>>, Error>;Expand description
The fallback function when service is rejected by sentinel.
pub type Fallback<B> = fn(ServiceRequest, &Error) -> Result<ServiceResponse<EitherBody<B>>, Error>;The fallback function when service is rejected by sentinel.